<?php

declare(strict_types=1);

namespace Dedi\SyliusMegamenuPlugin\Entity;

use Dedi\SyliusMegamenuPlugin\Enum\EntryTypes;
use Sylius\Component\Resource\Model\TranslationInterface;

class DirectLinkCollectionEntry extends Entry implements DirectLinkCollectionEntryInterface
{
    /** @var bool */
    protected $opensInNewTab = false;

    protected string $name = '';

    public function opensInNewTab(): bool
    {
        return $this->opensInNewTab;
    }

    public function setOpensInNewTab(bool $opensInNewTab): DirectLinkCollectionEntryInterface
    {
        $this->opensInNewTab = $opensInNewTab;

        return $this;
    }

    public function getType(): string
    {
        return EntryTypes::DIRECT_LINK_COLLECTION;
    }

    public function getName(): string
    {
        return $this->name;
    }

    public function setName(?string $name): DirectLinkCollectionEntryInterface
    {
        $this->name = $name;

        return $this;
    }

    protected function createTranslation(): TranslationInterface
    {
        return new DirectLinkCollectionEntryTranslation();
    }

    public function getUrl(): ?string
    {
        /** @var DirectLinkCollectionEntryInterface $translation */
        $translation = $this->getTranslation();

        return $translation->getUrl();
    }

    public function setUrl(?string $url): DirectLinkCollectionEntryInterface
    {
        /** @var DirectLinkCollectionEntryInterface $translation */
        $translation = $this->getTranslation();
        $translation->setUrl($url);

        return $this;
    }

    public function getLabel(): ?string
    {
        /** @var DirectLinkCollectionEntryInterface $translation */
        $translation = $this->getTranslation();

        return $translation->getLabel();
    }

    public function setLabel(?string $label): DirectLinkCollectionEntryInterface
    {
        /** @var DirectLinkCollectionEntryInterface $translation */
        $translation = $this->getTranslation();
        $translation->setLabel($label);

        return $this;
    }
}
